@@ -236,8 +236,7 @@ storeLayer <- function(meta, g, g.data.varied){
 #'   determine how. If it is set to "browseURL" then we use a file URL
 #'   (be sure to configure your browser to allow access to local
 #'   files, as some browsers block this by default). Otherwise
-#'   (default) if servr package is installed, we use
-#'   \code{servr::httd(out.dir)}.
+#'   (default) we use \code{servr::httd(out.dir)}.
 #' @param css.file character string for non-empty css file to
 #'   include. Provided file will be copied to the output directory as
 #'   styles.css
@@ -658,11 +657,7 @@ animint2dir <- function(plot.list, out.dir = NULL,
       u <- normalizePath(file.path(out.dir, "index.html"))
       browseURL(u)
     } else {
-      if (requireNamespace("servr")){
-        servr::httd(normalizePath(out.dir,winslash="/"))
-      } else {
-        warning('open.browser=TRUE but servr package not installed; try install.packages("servr") or options(animint.browser="browseURL")')
-      }
+      servr::httd(normalizePath(out.dir,winslash="/"))
     }
   }
 
